@@ -3,11 +3,12 @@ from django.apps import apps
 from django.contrib.contenttypes.models import ContentType
 from django import urls
 from django.db import connection, models, transaction
-from django.db.models import F, Q, Exists, OuterRef
+from django.db.models import Case, Exists, ExpressionWrapper, F, Func, OuterRef, Q, Value, When
+from django.conf import settings
+from django.urls import reverse
 from django.utils import timezone
 from django.utils.encoding import force_text
 from django.utils.functional import cached_property
-from historylinks import shortcuts as historylinks
 from reversion.models import Version
 
 from cms import sitemaps
@@ -19,17 +20,27 @@ class PageManager(OnlineBaseManager):
 
     '''Manager for Page objects.'''
 
+    def get_queryset(self):
+        queryset = super().get_queryset().annotate(is_canonical_page=ExpressionWrapper(
+            Q(owner_id__isnull=True) & Q(version_for_id__isnull=True), output_field=models.BooleanField()
+        ))
+
+        return queryset
+
     def select_published(self, queryset, page_alias=None):
         '''Selects only published pages.'''
         queryset = super().select_published(queryset)
         now = timezone.now().replace(second=0, microsecond=0)
         # Perform local filtering.
+        queryset = queryset.filter(version_for_id__isnull=True)
         queryset = queryset.filter(
-            Q(publication_date=None) | Q(publication_date__lte=now))
+            Q(publication_date=None) | Q(publication_date__lte=now)
+        )
         queryset = queryset.filter(Q(expiry_date=None) | Q(expiry_date__gt=now))
 
         # Perform parent ordering.
         offline_ancestors = self._queryset_class(model=self.model, using=self._db, hints=self._hints).filter(
+            Q(version_for_id__isnull=True),
             Q(left__lt=OuterRef('left')) & Q(right__gt=OuterRef('right')),
             Q(country_group_id__isnull=True) | Q(country_group_id=OuterRef('country_group_id')),
             Q(is_online=False) | Q(publication_date__gt=now) | Q(expiry_date__lte=now),
@@ -40,7 +51,11 @@ class PageManager(OnlineBaseManager):
 
     def get_homepage(self):
         '''Returns the site homepage.'''
-        return self.get(parent=None, is_content_object=False)
+        return self.get(parent=None, is_canonical_page=True)
+
+
+not_in_tree_q = Q(left__isnull=True) & Q(right__isnull=True)
+in_tree_q = Q(left__isnull=False) & Q(right__isnull=False)
 
 
 class Page(PageBase):
@@ -62,15 +77,13 @@ class Page(PageBase):
     left = models.IntegerField(
         editable=False,
         db_index=True,
+        null=True,
     )
 
     right = models.IntegerField(
         editable=False,
         db_index=True,
-    )
-
-    is_content_object = models.BooleanField(
-        default=False
+        null=True,
     )
 
     country_group = models.ForeignKey(
@@ -88,14 +101,42 @@ class Page(PageBase):
         on_delete=models.CASCADE,
     )
 
+    version = models.IntegerField(
+        default=1,
+    )
+
+    version_for = models.ForeignKey(
+        'self',
+        blank=True,
+        null=True,
+        related_name='version_set',
+        on_delete=models.CASCADE,
+    )
+
+    version_name = models.CharField(
+        max_length=100,
+        help_text='Used to identify this version in the admin',
+        blank=True,
+        null=True,
+        verbose_name='draft name'
+    )
+
+    version_publication_date = models.DateTimeField(
+        blank=True,
+        null=True,
+        help_text='The date this version will be published',
+        verbose_name='publish on',
+    )
+
     @cached_property
     def children(self):
         '''The child pages for this page.'''
         children = []
-        if self.right - self.left > 1:  # Optimization - don't fetch children
+        page = self.canonical_version
+        if page.right - page.left > 1:  # Optimization - don't fetch children
             #  we know aren't there!
-            for child in self.child_set.filter(is_content_object=False):
-                child.parent = self
+            for child in page.child_set.filter(is_canonical_page=True):
+                child.parent = page
                 children.append(child)
         return children
 
@@ -222,7 +263,7 @@ class Page(PageBase):
     def save(self, *args, **kwargs):
         '''Saves the page.'''
 
-        if self.is_content_object is False:
+        if self._is_canonical_page:
             with connection.cursor() as cursor:
                 cursor.execute('LOCK TABLE {} IN ROW SHARE MODE'.format(Page._meta.db_table))
 
@@ -231,7 +272,7 @@ class Page(PageBase):
                     (page['id'], page)
                     for page
                     in Page.objects.filter(
-                        is_content_object=False
+                        is_canonical_page=True
                     ).select_for_update().values(
                         'id',
                         'parent_id',
@@ -307,32 +348,114 @@ class Page(PageBase):
     @transaction.atomic
     def delete(self, *args, **kwargs):
         '''Deletes the page.'''
-        list(Page.objects.all().select_for_update().values_list(
-            'left',
-            'right'
-        ))  #
-        # Lock entire
-        #  table.
-        super().delete(*args, **kwargs)
-        # Update the entire tree.
-        self._excise_branch()
+        if self._is_canonical_page:
+            list(Page.objects.filter(is_canonical_page=True).select_for_update().values_list(
+                'left',
+                'right',
+            ))  #
+            # Lock entire
+            #  table.
+            super().delete(*args, **kwargs)
+            # Update the entire tree.
+            self._excise_branch()
+        else:
+            super().delete(*args, **kwargs)
 
     def last_modified(self):
         versions = Version.objects.get_for_object(self)
         if versions.count() > 0:
             latest_version = versions[:1][0]
             return '{} by {}'.format(
-                latest_version.revision.date_created.strftime('%Y-%m-%d %H:%M:%S'),
+                latest_version.revision.date_created.strftime('%d/%m/%Y %H:%M'),
                 latest_version.revision.user
             )
         return '-'
 
+    def get_language_pages(self):
+        if self.version_for:
+            return self.version_for.get_language_pages()
+        if self.owner:
+            return self.owner.get_language_pages()
+
+        current_page_qs = Page.objects.filter(pk=self.pk)
+        return self.owner_set.exclude(version_for_id__isnull=False).union(current_page_qs)
+
+    def get_versions(self):
+        if self.version_for_id:
+            parent_page_qs = Page.objects.filter(pk=self.version_for_id)
+            return self.version_for.version_set.union(parent_page_qs).order_by('version_for_id', '-version').reverse()
+
+        current_page_qs = Page.objects.filter(pk=self.pk)
+        return self.version_set.union(current_page_qs).order_by('version_for_id', '-version').reverse()
+
+    def get_admin_url(self):
+        if getattr(settings, 'PAGES_VERSIONING', False) and not self.version_for_id:
+            return reverse('admin:pages_page_overview', kwargs={'object_id':self.id})
+        return reverse('admin:pages_page_change', kwargs={'object_id':self.id})
+
+    def get_preview_url(self):
+        url = super().get_preview_url()
+        if self.version_for_id:
+            return f'{url}&version={self.version}'
+        return url
+
+    def get_public_preview_url(self):
+        url = super().get_public_preview_url()
+        if self.version_for_id:
+            return f'{url}&version={self.version}'
+        return url
+
+    def get_language(self):
+        if self.country_group:
+            return str(self.country_group)
+        try:
+            return Country.objects.select_related('group').get(default=True).group
+        except Country.DoesNotExist:
+            return None
+
+    def get_version_name(self):
+        return self.version_name or f'Version {self.version}'
+
+    @cached_property
+    def canonical_version(self):
+        if self.owner:
+            return self.owner.canonical_version
+        if self.version_for:
+            return self.version_for.canonical_version
+        return self
+
+    @property
+    def _is_canonical_page(self):
+        # The name is due to the fact we can't clash with the qs annotation name
+        return not (self.owner_id or self.version_for_id)
+
     class Meta:
-        unique_together = (('parent', 'slug', 'country_group'),)
         ordering = ('left',)
 
-
-historylinks.register(Page)
+        constraints = [
+            models.UniqueConstraint(
+                fields=['parent', 'slug'],
+                condition=Q(version_for_id__isnull=True) & Q(country_group__isnull=True),
+                name='unique_page_urls',
+            ),
+            models.UniqueConstraint(
+                fields=['country_group', 'owner'],
+                condition=Q(version_for_id__isnull=True),
+                name='unique_language_versions',
+            ),
+            models.CheckConstraint(
+                check=(Q(version_for_id__isnull=False) & not_in_tree_q) | Q(version_for_id__isnull=True),
+                name='versions_not_in_page_tree',
+            ),
+            models.CheckConstraint(
+                check=(Q(owner_id__isnull=False) & not_in_tree_q) | Q(owner_id__isnull=True),
+                name='translations_not_in_page_tree',
+            ),
+            models.CheckConstraint(
+                check=(Q(version_for_id__isnull=True) & Q(owner_id__isnull=True) & in_tree_q) | Q(version_for_id__isnull=False) | Q(owner_id__isnull=False),
+                name='page_mptt_values',
+            )
+        ]
 
 
 class PageSitemap(sitemaps.PageBaseSitemap):
