@@ -1,6 +1,7 @@
 from django.contrib import admin
 
-from cms.apps.testing_models.models import TestInlineModelNoPage, TestInlineModel
+from cms.apps.pages.admin import page_admin
+from cms.apps.testing_models.models import TestInlineModelNoPage, TestInlineModel, TestPageContentWithFields
 
 
 # Test-only model admins
@@ -10,3 +11,5 @@ class TestInlineModelNoPageInline(admin.StackedInline):
 
 class TestInlineModelInline(admin.StackedInline):
     model = TestInlineModel
+
+page_admin.register_content_inline(TestPageContentWithFields, TestInlineModelInline)
